@@ -19,15 +19,15 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3.setCancelButton(0);
     progress3.setValue(0);
     progress3.show();
-    readdirs();
     progress3.setValue(5);
+    readdirs();
     oldfonts();
     progress3.setValue(20);
     readSettings();
     progress3.setValue(30);
     QRegExp regexer("^\\#[0-9a-fA-F]{6,6}$");
     progress3.setValue(35);
-    QRegExp regexer_icon("^[0-9]{1,3}$");
+    QRegExp regexer_icon("^[0-9]{2,3}$");
     progress3.setValue(45);
     QRegExp regexer_book("^[0-9]{2,3}$");
     progress3.setValue(50);
@@ -45,6 +45,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->lineEdit->setValidator(new QRegExpValidator(regexer_icon, ui->lineEdit));
     ui->lineEdit_2->setValidator(new QRegExpValidator(regexer_book, ui->lineEdit_2));
     ui->Snap->setValidator(new QRegExpValidator(regexer_snap, ui->Snap));
+    ui->Opacity->setValidator(new QRegExpValidator(regexer_icon, ui->Opacity));
     progress3.setValue(80);
     QImage png("/opt/theme-customizer/customizer.png");
     QPixmap image;
@@ -172,6 +173,7 @@ void MainWindow::writeSettings()
     sett.setValue("iconset", ui->Iconset->currentIndex());
     sett.setValue("appsize", ui->lineEdit->text());
     sett.setValue("booksize", ui->lineEdit_2->text());
+    sett.setValue("opacity", ui->Opacity->text());
 
     QString Icons;
     if ( ui->Icons->checkState() == Qt::Checked ) {
@@ -188,12 +190,14 @@ void MainWindow::readSettings()
     int icons = sett.value("icons").toInt();
     int snap = sett.value("snap").toInt();
     int fontsize = sett.value("fontsize").toInt();
-    int iconset = sett.value("iconset").toInt();
+//    int iconset = sett.value("iconset").toInt();
     int appsize = sett.value("appsize").toInt();
     int booksize = sett.value("booksize").toInt();
+    int opacity = sett.value("opacity").toInt();
     QString appsizestring = sett.value("appsize").toString();
     QString booksizestring = sett.value("booksize").toString();
     QString snapstring = sett.value("snap").toString();
+    QString opacitystring = sett.value("opacity").toString();
     // ui->Icons->setCurrentIndex(icons);
     // ui->Snap->setCurrentIndex(snap);
 
@@ -220,6 +224,12 @@ void MainWindow::readSettings()
     ui->Snap->setText(snapstring);
     ui->horizontalSlider_3->setValue(snap);
     }
+
+    if ( opacity > 0 ) {
+    ui->Opacity->setText(opacitystring);
+    ui->horizontalSlider_4->setValue(opacity);
+    }
+
 }
 
 void MainWindow::on_pushButton_clicked()
@@ -247,7 +257,7 @@ void MainWindow::on_pushButton_clicked()
         progress.setWindowTitle(varattu);
         progress.setCancelButton(0);
         QStringList arguments;
-        arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8;
+        arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
         QProcess *process = new QProcess(this);
         connect(process, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
         process->start("/sbin/launchcustomizer", arguments);
@@ -310,6 +320,12 @@ void MainWindow::on_horizontalSlider_3_valueChanged(int value)
     ui->Snap->setText(slaideri3);
 }
 
+void MainWindow::on_horizontalSlider_4_valueChanged(int value)
+{
+    QString slaideri4 = QString::number(value);
+    ui->Opacity->setText(slaideri4);
+}
+
 void MainWindow::on_fontprimary_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
@@ -444,6 +460,13 @@ void MainWindow::on_Snap_editingFinished()
     ui->horizontalSlider_3->setValue(svalue);
 }
 
+void MainWindow::on_Opacity_editingFinished()
+{
+    QString slvalue = ui->Opacity->text();
+    int svalue = slvalue.toInt();
+    ui->horizontalSlider_4->setValue(svalue);
+}
+
 void MainWindow::on_checkBoxActivate_stateChanged(int )
 {
     if ( ui->checkBoxActivate->checkState() == Qt::Checked ) {
