@@ -118,6 +118,11 @@
         <source>Snap-to-grid size</source>
         <translation>Snap-to-grid koko</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Widget opacity %</source>
+        <translation>Widgettien näkyvyys %</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
         <source>App shortcut size</source>
