@@ -56,7 +56,7 @@
     <message>
         <location filename="mainwindow.ui" line="192"/>
         <source>Font colors</source>
-        <translation>Teckenfärger</translation>
+        <translation>Teckensnittsfärger</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="224"/>
@@ -71,12 +71,12 @@
     <message>
         <location filename="mainwindow.ui" line="260"/>
         <source>Active font</source>
-        <translation>Aktivt teckensnitt</translation>
+        <translation>Aktivt</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="278"/>
         <source>Disabled font</source>
-        <translation>Inaktivt teckensnitt</translation>
+        <translation>Inaktivt</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="360"/>
@@ -118,6 +118,11 @@
         <source>Snap-to-grid size</source>
         <translation>Fäst-mot-rutnät</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Widget opacity %</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
         <source>App shortcut size</source>
@@ -193,7 +198,7 @@
     <message>
         <location filename="mainwindow.cpp" line="361"/>
         <source>Do you want to import fonts from MyDocs?</source>
-        <translation>Vill du importera teckensnitt från MyDocs?</translation>
+        <translation>Importera från MyDocs?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="362"/>
